@@ -21,23 +21,18 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
-#include <QRect>
-#include <QPainter>
-#include <QPalette>
 #include <QKeyEvent>
 #include <QFocusEvent>
 #include <QTimer>
+#include <QLocale>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <klocale.h>
-
 // ----------------------------------------------------------------------------
 // Project Includes
 
-class kMyMoneyLineEdit::Private
+class KMyMoneyLineEdit::Private
 {
 public:
   /**
@@ -56,7 +51,7 @@ public:
   bool  skipSelectAll;
 };
 
-kMyMoneyLineEdit::kMyMoneyLineEdit(QWidget *w, bool forceMonetaryDecimalSymbol, Qt::Alignment alignment) :
+KMyMoneyLineEdit::KMyMoneyLineEdit(QWidget *w, bool forceMonetaryDecimalSymbol, Qt::Alignment alignment) :
     KLineEdit(w),
     d(new Private)
 {
@@ -65,28 +60,28 @@ kMyMoneyLineEdit::kMyMoneyLineEdit(QWidget *w, bool forceMonetaryDecimalSymbol,
   skipSelectAll(false);
 }
 
-kMyMoneyLineEdit::~kMyMoneyLineEdit()
+KMyMoneyLineEdit::~KMyMoneyLineEdit()
 {
   delete d;
 }
 
-void kMyMoneyLineEdit::skipSelectAll(bool skipIt)
+void KMyMoneyLineEdit::skipSelectAll(bool skipIt)
 {
   d->skipSelectAll = skipIt;
 }
 
-void kMyMoneyLineEdit::resetText()
+void KMyMoneyLineEdit::resetText()
 {
   setText(d->m_text);
 }
 
-void kMyMoneyLineEdit::loadText(const QString& text)
+void KMyMoneyLineEdit::loadText(const QString& text)
 {
   d->m_text = text;
   setText(text);
 }
 
-void kMyMoneyLineEdit::focusOutEvent(QFocusEvent *ev)
+void KMyMoneyLineEdit::focusOutEvent(QFocusEvent *ev)
 {
   // if the current text is not in the list of
   // possible completions, we have a new payee
@@ -101,7 +96,7 @@ void kMyMoneyLineEdit::focusOutEvent(QFocusEvent *ev)
     repaint();
 }
 
-void kMyMoneyLineEdit::focusInEvent(QFocusEvent *ev)
+void KMyMoneyLineEdit::focusInEvent(QFocusEvent *ev)
 {
   KLineEdit::focusInEvent(ev);
   // select the text so it can be edited by the user - only if the widget
@@ -118,20 +113,20 @@ void kMyMoneyLineEdit::focusInEvent(QFocusEvent *ev)
   }
 }
 
-void kMyMoneyLineEdit::keyReleaseEvent(QKeyEvent* k)
+void KMyMoneyLineEdit::keyReleaseEvent(QKeyEvent* k)
 {
   if (d->m_forceMonetaryDecimalSymbol) {
     if (k->modifiers() & Qt::KeypadModifier) {
       if (k->key() == Qt::Key_Comma
           || k->key() == Qt::Key_Period) {
-        if (KGlobal::locale()->monetaryDecimalSymbol() == ",") {
+        if (QLocale().decimalPoint() == QLatin1Char(',')) {
           QKeyEvent newk(k->type(), Qt::Key_Comma, k->modifiers(), ",", k->isAutoRepeat(), k->count());
           KLineEdit::keyReleaseEvent(&newk);
           k->accept();
           return;
         }
 
-        if (KGlobal::locale()->monetaryDecimalSymbol() == ".") {
+        if (QLocale().decimalPoint() == QLatin1Char('.')) {
           QKeyEvent newk(k->type(), Qt::Key_Comma, k->modifiers(), ".", k->isAutoRepeat(), k->count());
           KLineEdit::keyReleaseEvent(&newk);
           k->accept();
@@ -143,20 +138,20 @@ void kMyMoneyLineEdit::keyReleaseEvent(QKeyEvent* k)
   KLineEdit::keyReleaseEvent(k);
 }
 
-void kMyMoneyLineEdit::keyPressEvent(QKeyEvent* k)
+void KMyMoneyLineEdit::keyPressEvent(QKeyEvent* k)
 {
   if (d->m_forceMonetaryDecimalSymbol) {
     if (k->modifiers() & Qt::KeypadModifier) {
       if (k->key() == Qt::Key_Comma
           || k->key() == Qt::Key_Period) {
-        if (KGlobal::locale()->monetaryDecimalSymbol() == ",") {
+        if (QLocale().decimalPoint() == QLatin1Char(',')) {
           QKeyEvent newk(k->type(), Qt::Key_Comma, k->modifiers(), ",", k->isAutoRepeat(), k->count());
           KLineEdit::keyPressEvent(&newk);
           k->accept();
           return;
         }
 
-        if (KGlobal::locale()->monetaryDecimalSymbol() == ".") {
+        if (QLocale().decimalPoint() == QLatin1Char('.')) {
           QKeyEvent newk(k->type(), Qt::Key_Period, k->modifiers(), ".", k->isAutoRepeat(), k->count());
           KLineEdit::keyPressEvent(&newk);
           k->accept();
