@@ -1,8 +1,10 @@
+
 /***************************************************************************
                           registersearchline.cpp
                              -------------------
     copyright            : (C) 2006 by Thomas Baumgart
     email                : ipwizard@users.sourceforge.net
+                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,26 +21,32 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
-#include <QApplication>
 #include <QLabel>
-#include <QToolButton>
 #include <QTimer>
 #include <QScrollBar>
+#include <QHBoxLayout>
+#include <QHash>
+#include <QIcon>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <ktoolbar.h>
-#include <kcombobox.h>
-#include <kiconloader.h>
-#include <klocale.h>
+#include <KComboBox>
+#include <KLocalizedString>
 
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include <kmymoneyutils.h>
+#include "kmymoneyutils.h"
+#include "register.h"
+#include "registeritem.h"
+#include "registerfilter.h"
+#include "icons/icons.h"
+#include "widgetenums.h"
 
+using namespace eWidgets;
 using namespace KMyMoneyRegister;
+using namespace Icons;
 
 class RegisterSearchLine::RegisterSearchLinePrivate
 {
@@ -47,48 +55,53 @@ public:
       reg(0),
       combo(0),
       queuedSearches(0),
-      status(RegisterFilter::Any) {}
+      status(eRegister::ItemState::Any) {}
 
   Register* reg;
   KComboBox* combo;
   QString search;
   int queuedSearches;
-  RegisterFilter::ItemState status;
+  eRegister::ItemState status;
 };
 
 RegisterSearchLine::RegisterSearchLine(QWidget* parent, Register* reg) :
     KLineEdit(parent),
     d(new RegisterSearchLinePrivate)
 {
-  setClearButtonShown(true);
+  setClearButtonShown(true); // it allows to emit KLineEdit::clearButtonClicked and is not equal in that sense to setClearButtonEnabled(true)
   init(reg);
 }
 
 void RegisterSearchLine::init(Register *reg)
 {
+  if (!parentWidget()->layout())
+    parentWidget()->setLayout(new QHBoxLayout);
+  parentWidget()->layout()->addWidget(this);
   d->reg = reg;
-  connect(this, SIGNAL(textChanged(QString)), this, SLOT(queueSearch(QString)));
+  connect(this, &QLineEdit::textChanged, this, &RegisterSearchLine::queueSearch);
 
   QLabel* label = new QLabel(i18nc("label for status combo", "Stat&us"), parentWidget());
+  parentWidget()->layout()->addWidget(label);
   d->combo = new KComboBox(parentWidget());
+  parentWidget()->layout()->addWidget(d->combo);
   // don't change the order of the following lines unless updating
   // the case labels in RegisterSearchLine::itemMatches() at the same time
-  d->combo->insertItem(RegisterFilter::Any, SmallIcon("system-run"), i18n("Any status"));
-  d->combo->insertItem(RegisterFilter::Imported, SmallIcon("document-import"), i18n("Imported"));
-  d->combo->insertItem(RegisterFilter::Matched, KMyMoneyUtils::overlayIcon("view-financial-transfer", "document-import"), i18n("Matched"));
-  d->combo->insertItem(RegisterFilter::Erroneous, SmallIcon("task-attention"), i18n("Erroneous"));
-  d->combo->insertItem(RegisterFilter::NotMarked, i18n("Not marked"));
-  d->combo->insertItem(RegisterFilter::NotReconciled, i18n("Not reconciled"));
-  d->combo->insertItem(RegisterFilter::Cleared, i18nc("Reconciliation state 'Cleared'", "Cleared"));
-  d->combo->setCurrentIndex(RegisterFilter::Any);
-  connect(d->combo, SIGNAL(activated(int)), this, SLOT(slotStatusChanged(int)));
-  connect(this, SIGNAL(clearButtonClicked()), this, SLOT(reset()));
+  d->combo->insertItem((int)eRegister::ItemState::Any, Icons::get(Icon::SystemRun), i18n("Any status"));
+  d->combo->insertItem((int)eRegister::ItemState::Imported, Icons::get(Icon::DocumentImport), i18n("Imported"));
+  d->combo->insertItem((int)eRegister::ItemState::Matched, Icons::get(Icon::TransactionMatch), i18n("Matched"));
+  d->combo->insertItem((int)eRegister::ItemState::Erroneous, Icons::get(Icon::TaskAttention), i18n("Erroneous"));
+  d->combo->insertItem((int)eRegister::ItemState::NotMarked, i18n("Not marked"));
+  d->combo->insertItem((int)eRegister::ItemState::NotReconciled, i18n("Not reconciled"));
+  d->combo->insertItem((int)eRegister::ItemState::Cleared, i18nc("Reconciliation state 'Cleared'", "Cleared"));
+  d->combo->setCurrentIndex((int)eRegister::ItemState::Any);
+  connect(d->combo, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &RegisterSearchLine::slotStatusChanged);
+  connect(this, &KLineEdit::clearButtonClicked, this, &RegisterSearchLine::reset);
 
   label->setBuddy(d->combo);
 
   if (reg) {
-    connect(reg, SIGNAL(destroyed()), this, SLOT(registerDestroyed()));
-    connect(reg, SIGNAL(itemAdded(RegisterItem*)), this, SLOT(itemAdded(RegisterItem*)));
+    connect(reg, &QObject::destroyed, this, &RegisterSearchLine::registerDestroyed);
+    connect(reg, &Register::itemAdded, this, &RegisterSearchLine::itemAdded);
   } else {
     setEnabled(false);
   }
@@ -102,15 +115,15 @@ RegisterSearchLine::~RegisterSearchLine()
 void RegisterSearchLine::setRegister(Register* reg)
 {
   if (d->reg) {
-    disconnect(d->reg, SIGNAL(destroyed()), this, SLOT(registerDestroyed()));
-    disconnect(d->reg, SIGNAL(itemAdded(RegisterItem*)), this, SLOT(itemAdded(RegisterItem*)));
+    disconnect(d->reg, &QObject::destroyed, this, &RegisterSearchLine::registerDestroyed);
+    disconnect(d->reg, &Register::itemAdded, this, &RegisterSearchLine::itemAdded);
   }
 
   d->reg = reg;
 
   if (reg) {
-    connect(reg, SIGNAL(destroyed()), this, SLOT(registerDestroyed()));
-    connect(reg, SIGNAL(itemAdded(RegisterItem*)), this, SLOT(itemAdded(RegisterItem*)));
+    connect(reg, &QObject::destroyed, this, &RegisterSearchLine::registerDestroyed);
+    connect(reg, &Register::itemAdded, this, &RegisterSearchLine::itemAdded);
   }
 
   setEnabled(reg != 0);
@@ -118,7 +131,7 @@ void RegisterSearchLine::setRegister(Register* reg)
 
 void RegisterSearchLine::slotStatusChanged(int status)
 {
-  d->status = static_cast<RegisterFilter::ItemState>(status);
+  d->status = static_cast<eRegister::ItemState>(status);
   updateSearch();
 }
 
@@ -164,19 +177,24 @@ void RegisterSearchLine::updateSearch(const QString& s)
   // it on screen
   if (focusItem && focusItem->isVisible()) {
     d->reg->update();
-    d->reg->ensureItemVisible(focusItem);
+     /* it's totally fine to call ensureFocusItemVisible instantly
+      * while narrowing (by adding another letter) filtered results
+      * because removing items from QTableWidget is fast
+      * but while widening (by removing some letter) filtered results
+      * QTableWidget lags and ensureFocusItemVisible() happens before
+      * its update and focused item isn't made visible therefore
+     */
+    QTimer::singleShot(500, d->reg, SLOT(ensureFocusItemVisible()));
   }
   // if the scrollbar's visibility changed, we need to resize the contents
   if (scrollBarVisible != d->reg->verticalScrollBar()->isVisible()) {
-    d->reg->resize(DetailColumn);
+    d->reg->resize((int)eTransaction::Column::Detail);
   }
 }
 
 void RegisterSearchLine::reset()
 {
   clear();
-  d->combo->setCurrentIndex(RegisterFilter::Any);
-  slotStatusChanged(RegisterFilter::Any);
 }
 
 void RegisterSearchLine::itemAdded(RegisterItem* item) const
@@ -204,12 +222,11 @@ public:
 
 
 RegisterSearchLineWidget::RegisterSearchLineWidget(Register* reg, QWidget* parent) :
-    KHBox(parent),
+    QWidget(parent),
     d(new RegisterSearchLineWidgetPrivate)
 {
   d->reg = reg;
-  setSpacing(6);
-  QTimer::singleShot(0, this, SLOT(createWidgets()));
+  createWidgets();
 }
 
 RegisterSearchLineWidget::~RegisterSearchLineWidget()
@@ -226,7 +243,11 @@ RegisterSearchLine* RegisterSearchLineWidget::createSearchLine(Register* reg)
 
 void RegisterSearchLineWidget::createWidgets()
 {
+  QHBoxLayout *searchLineLayout = new QHBoxLayout(this);
+  searchLineLayout->setSpacing(0);
+  searchLineLayout->setContentsMargins(0, 0, 0, 0);
   QLabel *label = new QLabel(i18nc("Filter widget label", "Fi&lter:"), this);
+  searchLineLayout->addWidget(label);
 
   d->searchLine = createSearchLine(d->reg);
   d->searchLine->show();
